==> hs-haxml-1.19.7.tbz: lib/HaXml-1.19.7/register.sh <==
#!/bin/sh

echo 'name: HaXml
version: 1.19.7
license: LGPL
copyright:
maintainer: author
stability:
homepage: http://www.cs.york.ac.uk/fp/HaXml/
package-url:
description: Haskell utilities for parsing, filtering, transforming and
             generating XML documents.
category: Text, XML
author: Malcolm Wallace <Malcolm.Wallace@cs.york.ac.uk>
exposed: True
exposed-modules: Text.XML.HaXml Text.XML.HaXml.ByteStringPP
                 Text.XML.HaXml.Combinators Text.XML.HaXml.DtdToHaskell.Convert
                 Text.XML.HaXml.DtdToHaskell.Instance
                 Text.XML.HaXml.DtdToHaskell.TypeDef Text.XML.HaXml.Escape
                 Text.XML.HaXml.Html.Generate Text.XML.HaXml.Html.Parse
                 Text.XML.HaXml.Html.ParseLazy Text.XML.HaXml.Html.Pretty
                 Text.XML.HaXml.Lex Text.XML.HaXml.OneOfN Text.XML.HaXml.Parse
                 Text.XML.HaXml.ParseLazy Text.XML.HaXml.Posn Text.XML.HaXml.Pretty
                 Text.XML.HaXml.SAX Text.XML.HaXml.ShowXmlLazy Text.XML.HaXml.Types
                 Text.XML.HaXml.TypeMapping Text.XML.HaXml.Util
                 Text.XML.HaXml.Validate Text.XML.HaXml.Verbatim
                 Text.XML.HaXml.Wrappers Text.XML.HaXml.XmlContent
                 Text.XML.HaXml.XmlContent.Parser Text.XML.HaXml.XmlContent.Haskell
                 Text.XML.HaXml.Xtract.Combinators Text.XML.HaXml.Xtract.Lex
                 Text.XML.HaXml.Xtract.Parse
hidden-modules:
import-dirs: /usr/local/lib/HaXml-1.19.7/ghc-6.10.4
library-dirs: /usr/local/lib/HaXml-1.19.7/ghc-6.10.4
hs-libraries: HSHaXml-1.19.7
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.1.0.0 bytestring-0.9.1.4 containers-0.2.0.1
         filepath-1.1.0.2 haskell98-1.0.1.0 polyparse-1.3 pretty-1.0.1.0
         random-1.0.0.1
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/HaXml-1.19.7/html/HaXml.haddock
haddock-html: /usr/local/share/doc/HaXml-1.19.7/html' | /usr/local/bin/ghc-pkg update -

==> hs-haxml-1.20.tbz: lib/HaXml-1.20/register.sh <==
#!/bin/sh

echo 'name: HaXml
version: 1.20
license: LGPL
copyright:
maintainer: author
stability:
homepage: http://www.cs.york.ac.uk/fp/HaXml/
package-url:
description: Haskell utilities for parsing, filtering, transforming and
             generating XML documents.
category: Text, XML
author: Malcolm Wallace <Malcolm.Wallace@cs.york.ac.uk>
exposed: True
exposed-modules: Text.XML.HaXml Text.XML.HaXml.ByteStringPP
                 Text.XML.HaXml.Combinators Text.XML.HaXml.DtdToHaskell.Convert
                 Text.XML.HaXml.DtdToHaskell.Instance
                 Text.XML.HaXml.DtdToHaskell.TypeDef Text.XML.HaXml.Escape
                 Text.XML.HaXml.Html.Generate Text.XML.HaXml.Html.Parse
                 Text.XML.HaXml.Html.ParseLazy Text.XML.HaXml.Html.Pretty
                 Text.XML.HaXml.Lex Text.XML.HaXml.OneOfN Text.XML.HaXml.Parse
                 Text.XML.HaXml.ParseLazy Text.XML.HaXml.Posn Text.XML.HaXml.Pretty
                 Text.XML.HaXml.SAX Text.XML.HaXml.ShowXmlLazy Text.XML.HaXml.Types
                 Text.XML.HaXml.TypeMapping Text.XML.HaXml.Util
                 Text.XML.HaXml.Validate Text.XML.HaXml.Verbatim
                 Text.XML.HaXml.Wrappers Text.XML.HaXml.XmlContent
                 Text.XML.HaXml.XmlContent.Parser Text.XML.HaXml.XmlContent.Haskell
                 Text.XML.HaXml.Xtract.Combinators Text.XML.HaXml.Xtract.Lex
                 Text.XML.HaXml.Xtract.Parse
hidden-modules:
import-dirs: /usr/local/lib/HaXml-1.20/ghc-6.10.4
library-dirs: /usr/local/lib/HaXml-1.20/ghc-6.10.4
hs-libraries: HSHaXml-1.20
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.1.0.0 bytestring-0.9.1.4 containers-0.2.0.1
         filepath-1.1.0.2 haskell98-1.0.1.0 polyparse-1.4 pretty-1.0.1.0
         random-1.0.0.1
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/HaXml-1.20/html/HaXml.haddock
haddock-html: /usr/local/share/doc/HaXml-1.20/html' | /usr/local/bin/ghc-pkg update -
